@@ -46,9 +46,9 @@
 
 import click
 
-from pygeometa.core import generate_metadata, info, schemas
+from pygeometa.core import generate, info, schemas, validate
 
-__version__ = '0.7.0'
+__version__ = '0.8.0'
 
 
 @click.group()
@@ -57,6 +57,14 @@ def cli():
     pass
 
 
-cli.add_command(generate_metadata)
-cli.add_command(info)
-cli.add_command(schemas)
+@click.group()
+def metadata():
+    """Metadata management"""
+    pass
+
+
+metadata.add_command(generate)
+metadata.add_command(info)
+metadata.add_command(schemas)
+metadata.add_command(validate)
+cli.add_command(metadata)
